@@ -7,14 +7,14 @@ void Generator::debug(ostream &out) const
 
     key(out);
 
-    out << "if (d_debug)\n" <<
+    out << "if (d_debug__)\n" <<
         setw(d_indent + 4) << "" << flush;
 
     if (*d_line.rbegin() != '+')
-        out <<  "s_out << " << d_line << " << \"\\n\" << dflush;" << endl;
+        out <<  "s_out__ << " << d_line << " << \"\\n\" << dflush;" << endl;
     else
     {
         d_line.resize(d_line.length() - 1);
-        out <<  "s_out << " << d_line << ";" << endl;
+        out <<  "s_out__ << " << d_line << ";" << endl;
     }
 }
