@@ -7,6 +7,6 @@ void Generator::ltypePush(ostream &out) const
 
     key(out);
 
-    out << "*(d_lsp = &d_locationStack[d_stackIdx]) = d_loc;\n";
+    out << "*(d_lsp__ = &d_locationStack__[d_stackIdx__]) = d_loc__;\n";
 }
 
