@@ -5,7 +5,7 @@
 // The @-return value is not specified in bison's documentation. Is it not
 // used? Using the @ feature implies lsp-needed, which is set by implication
 
-void Parser::handleAtSign(size_t pos, size_t nElements) 
+void Parser::handleAtSign(size_t pos, int nElements, Block &block) 
 {
     int idx;                // extract the index, determine its length
     size_t replaceSize = 1 + extractIndex(&idx, pos + 1);
@@ -13,11 +13,12 @@ void Parser::handleAtSign(size_t pos, size_t nElements)
     ostringstream os;
     os << s_locationValueStack << "[" << indexToOffset(idx, nElements) << "]";
 
-    d_block.replace(pos, replaceSize, os.str());
+    block.replace(pos, replaceSize, os.str());
 
     if (!d_lspNeeded)
     {
-        msg() << "@ used in the action block at line " << d_block.line() <<
+        msg() << "@ used in the action block at line " << 
+                block.line() <<
                 ": %lsp-needed forced" << warning;
         d_lspNeeded = true;
     }
