@@ -6,20 +6,13 @@
 void Parser::setUnionDecl()
 {
     if (d_stackDecl.size())
-        lineMsg() << "%union or %stype multiply declared" << err;
+        lineMsg() << "%union or %stype multiply specified" << err;
+
+    (d_stackDecl = "union STYPE__\n" + d_scanner.block()) += ";\n";
 
-    d_stackDecl = "struct STYPE\n";
     d_unionDeclared = true;         // if a %union is used, then the rules
                                     // MUST have an associated return type if
                                     // a plain $$ is used. Also, a union must
                                     // be available if a $<field> construction
                                     // is used.
-
-    if (!d_scanner.block(&d_block))
-        lineMsg() << "`%union { ... }' expected" << err;
-    else
-        (d_stackDecl += d_block) += ";\n";
-
-    if (d_scanner.lex() != ';')                     // trailing ; is ok
-        d_scanner.unget();                          // but none is ok too.
 }
