@@ -28,7 +28,6 @@ class SRConflict: public SRSolution
                    std::vector<size_t> const &reducible);
 
         void inspect();
-
                             // returns # of shifts that were removed
         size_t removeShifts(Next::Vector &nextVector);
 
@@ -41,7 +40,7 @@ class SRConflict: public SRSolution
         void processShiftReduceConflict(Next::ConstIter const &next, 
                                         size_t itemIdx);
 
-        static void visitReduction(size_t const &idx, SRConflict &context);
+        static void visitReduction(size_t idx, SRConflict &context);
 };
 
 inline size_t SRConflict::nConflicts()
