@@ -2,10 +2,14 @@
 
 ostream &State::insertExt(ostream &out) const
 {
-    OM::setType(OM::EXTENDED);
-
     out << "State " << d_idx << ":\n";
 
+    Terminal::inserter(&Terminal::plainName);
+    NonTerminal::inserter(&NonTerminal::nameAndFirstset);
+    Item::inserter(&Item::pNrDotItem);
+    StateItem::inserter(&StateItem::itemContext);
+    Next::inserter(&Next::transitionKernel);
+
     for (size_t idx = 0; idx < d_itemVector.size(); ++idx)
         out <<  idx << ": " << d_itemVector[idx] << endl;
 
@@ -21,10 +25,7 @@ ostream &State::insertExt(ostream &out) const
         out << endl;                    
     }
 
-    OM::setType(OM::STD);
-
-    return out << d_srConflict << d_rrConflict << "\n";
+    return out << d_srConflict << d_rrConflict << '\n';
 }
 
 
-
