@@ -16,17 +16,17 @@ Terminal::Terminal(string const &name, Type type,
 {
     if (name.find("'\\x") == 0)
     {
-        char charRepresentation;
+        int charRepresentation;
         istringstream convert(name.substr(3));
-        convert >> hex >> reinterpret_cast<int &>(charRepresentation);
+        convert >> hex >> charRepresentation;
         if (isprint(charRepresentation))
         {
             d_readableLiteral = "'";
-            d_readableLiteral.append(1, charRepresentation);
+            d_readableLiteral.append(1, static_cast<char>(charRepresentation));
             d_readableLiteral += "'";
         }
     }
-       
+
     lineMsg() << "Defining terminal " << d_readableLiteral << ": pri = " << 
                                                         d_precedence << spool;
     msg() << info;
