@@ -5,10 +5,17 @@ void Writer::reduction(Element const *symb, ReductionContext &context)
     Symbol const *symbol = dynamic_cast<Symbol const *>(symb);
     ostringstream out;
 
-    out << OM::sr << symbol;
+    Terminal::inserter(&Terminal::nameOrValue);
+    NonTerminal::inserter(&NonTerminal::value);
+
+    out << symbol;
     context.table << out.str() << -static_cast<int>(context.ruleNr);
 
     out.str("");
+
+    Terminal::inserter(&Terminal::plainName);
+    NonTerminal::inserter(&NonTerminal::plainName);
+
     out << "// " << symbol;
     context.table << out.str();
 }
